
library(readxl)
library(tidyr)
library(dplyr)
library(ggrepel)

# Figure 1 - estimates of global Rs

readxl::read_xlsx("Global_Rs_estimates.xlsx") %>% 
  separate(Trend_range, into = c("Trend_minyr", "Trend_maxyr"), convert = TRUE) %>% 
  mutate(Trend_min = Global_Rs_PgC + (Trend_minyr - Estimate_yr) * Trend_PgC_yr,
         Trend_max = Global_Rs_PgC + (Trend_maxyr - Estimate_yr) * Trend_PgC_yr,
         Global_Rs_PgC = if_else(is.na(Trend_max), Global_Rs_PgC, Trend_max),
         Estimate_yr = if_else(is.na(Trend_max), Estimate_yr, as.double(Trend_maxyr))) %>% 
  arrange(Estimate_yr) ->
  x

library(ggplot2)
theme_set(theme_bw())

x$isZhao = x$Reference == "Zhao et al. (2017)"
x$Number <- seq_len(nrow(x))

fig1 <- ggplot(x, aes(Estimate_yr, Global_Rs_PgC, color = isZhao)) + geom_point(size = 4) + 
  geom_segment(aes(x = Trend_minyr, y = Trend_min, xend = Trend_maxyr, yend = Trend_max), linetype = 2) +
  geom_errorbar(aes(ymin = Global_Rs_95CI_low, ymax = Global_Rs_95CI_high)) +
  scale_color_manual(values = c("darkgrey", "red"), guide = FALSE) +
  xlab("Year of estimate") + ylab(expression(Global~R[S]~(Pg~C~yr^{-1}))) +
  geom_text_repel(aes(label = Number), size = 3)
#  scale_size_manual(values = c(1, 2), guide = FALSE)

print(fig1)
ggsave("fig1-global_rs.png", width = 6, height = 4)

print(select(x, Number, Reference))


# Figure 2 - changing (geographical) sources over time

# Continent-country data from https://old.datahub.io/dataset/countries-continents/resource/aa08c34c-57e8-4e15-bd36-969bee26aba5
continents <- readr::read_csv("Countries-Continents.csv")
continents$Country[continents$Country=="US"] <- "USA"
continents$Country[continents$Country=="Russian Federation"] <- "Russia"
continents <- bind_rows(continents, tibble(Country = "Antarctica", Continent="Antarctica"))
readr::read_csv("srdb-data.csv") %>% 
  select(Country, Study_midyear) %>% 
  mutate(Country = trimws(Country), yearbin = 5 + 5 * floor(Study_midyear/5)) %>% 
  left_join(continents) %>%
  filter(!is.na(Continent), !is.na(yearbin)) %>% 
  arrange(Study_midyear) %>% 
  group_by(Continent, yearbin) %>% 
  summarise(n = n()) %>% 
  ungroup -> y

y_full <- expand.grid(yearbin = unique(y$yearbin), Continent = unique(y$Continent), stringsAsFactors = FALSE)
y <- left_join(y_full, y) %>% replace_na(list(n = 0))

y %>% 
  arrange(yearbin) %>% 
  group_by(Continent) %>% 
  mutate(cumn = cumsum(n)) -> ycum

fig2 <- ggplot(ycum, aes(yearbin, cumn, fill=Continent)) + geom_area(position="stack") + xlim(c(1960, 2015)) +
  xlab("Year") + ylab("Cumulative number of observations") +
  theme(legend.position = c(0.2, 0.65))
print(fig2)

ggsave("fig2-rs_studies.png", width = 6, height = 4)
